@@ -15,25 +15,29 @@ class TestMetaBlockUnit:
         """Test the correct usage of the message_on_fail parameter of meta_block check."""
 
         # Test message_on_fail for a failing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(False, message_on_fail="We want to see this message")
-        """)
+        """
+        )
         _, _, etss = adaptavist_mock
         pytester.runpytest("--adaptavist")
         assert "We want to see this message" in etss.call_args.kwargs["comment"]
 
         # Test message_on_fail for a passing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True, message_on_fail="We don't want to see this message")
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         assert "We don't want to see this message" not in etss.call_args.kwargs["comment"]
 
@@ -41,38 +45,44 @@ class TestMetaBlockUnit:
         """Test the correct usage of the message_on_pass parameter of meta_block check."""
 
         # Test message_on_pass for a passing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True, message_on_pass="We want to see this message")
-        """)
+        """
+        )
         _, _, etss = adaptavist_mock
         pytester.runpytest("--adaptavist")
         assert "We want to see this message" in etss.call_args.kwargs["comment"]
 
         # Test message_on_pass for a failing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(False, message_on_pass="We don't want to see this message")
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         assert "We don't want to see this message" not in etss.call_args.kwargs["comment"]
 
     def test_description(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test the correct usage of the description parameter of meta_block check."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True, description="This should be displayed twice")
                     mb_1.check(False, description="This should be displayed twice")
-        """)
+        """
+        )
         _, _, etss = adaptavist_mock
         pytester.runpytest("--adaptavist")
         assert etss.call_args.kwargs["comment"].count("This should be displayed twice") == 2
@@ -83,25 +93,29 @@ class TestMetaBlockUnit:
         pytester.maketxtfile(first_file="foo")
 
         # Test attachment for a passing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True, attachment="first_file.txt")
-        """)
+        """
+        )
         with patch("adaptavist.Adaptavist.add_test_script_attachment") as atsa:
             pytester.runpytest("--adaptavist")
             assert "first_file.txt" in atsa.call_args.kwargs["filename"]
 
         # Test attachment for a failing test case
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(False, attachment="first_file.txt")
-        """)
+        """
+        )
         with patch("adaptavist.Adaptavist.add_test_script_attachment") as atsa:
             pytester.runpytest("--adaptavist")
             assert "first_file.txt" in atsa.call_args.kwargs["filename"]
@@ -109,14 +123,16 @@ class TestMetaBlockUnit:
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_description_of_test_steps_printed(self, pytester: pytest.Pytester):
         """Test if the description of testcases is printed, if pytest is started with high verbosity."""
-        pytester.makepyfile('''
+        pytester.makepyfile(
+            '''
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     """Description of test step 1"""
                     mb_1.check(True)
-        ''')
+        '''
+        )
 
         # Low verbosity
         report = pytester.runpytest("--adaptavist")
@@ -128,7 +144,8 @@ class TestMetaBlockUnit:
 
     def test_adaptavist_call_metablock(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test if all meta blocks are reported to adaptavist."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -138,7 +155,8 @@ class TestMetaBlockUnit:
                     assert True
                 with meta_block(3):
                     assert False
-        """)
+        """
+        )
         _, etrs, _ = adaptavist_mock
         pytester.runpytest("--adaptavist")
         assert etrs.call_count == 4  # 3 meta blocks and 1 overall result
@@ -146,7 +164,8 @@ class TestMetaBlockUnit:
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_meta_block_timeout(self, pytester: pytest.Pytester):
         """Test if a meta block is timed out."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             from time import sleep
             import pytest
 
@@ -154,14 +173,16 @@ class TestMetaBlockUnit:
                 with meta_block(1, 1):
                     sleep(2)
                     assert True
-        """)
+        """
+        )
         outcome = pytester.runpytest("--adaptavist").parseoutcomes()
         assert outcome["skipped"] == 1
 
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_meta_block_timeout_fail(self, pytester: pytest.Pytester):
         """Test if a meta block is timed out with fail action."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             from time import sleep
             import pytest
 
@@ -169,26 +190,30 @@ class TestMetaBlockUnit:
                 with meta_block(1, timeout=1, action_on_timeout=0):
                     sleep(2)
                     assert True
-        """)
+        """
+        )
         outcome = pytester.runpytest("--adaptavist").parseoutcomes()
         assert outcome["failed"] == 1
 
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_meta_block_check_unknown_arguments(self, pytester: pytest.Pytester):
         """Test if meta_block handles unknown keyword arguments correctly."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True, unknown_kwargs=123)
-        """)
+        """
+        )
         report = pytester.runpytest("--adaptavist")
         assert any(("Unknown arguments: {'unknown_kwargs': 123}" in x for x in report.outlines))
 
     def test_meta_block_assume(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test if meta_block is using assume correctly. Step 2 must be executed even if step 1 fails."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -196,14 +221,16 @@ class TestMetaBlockUnit:
                     mb_1.check(False)
                 with meta_block(2) as mb_2:
                     mb_2.check(True)
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         _, _, etss = adaptavist_mock
         assert etss.call_count == 2
 
     def test_meta_block_fail_method(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test Action.FAIL_METHOD. Step 2 must not be executed as step 1 will fail."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -211,7 +238,8 @@ class TestMetaBlockUnit:
                     mb_1.check(False, action_on_fail=mb_1.Action.FAIL_METHOD)
                 with meta_block(2) as mb_2:
                     mb_2.check(True)
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         _, _, etss = adaptavist_mock
         assert etss.call_count == 1
@@ -219,7 +247,8 @@ class TestMetaBlockUnit:
     def test_meta_block_stop_context(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test Action.STOP_CONTEXT. The second check in meta_block 1 must not be executed, but step 2 must be executed."""
 
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -228,7 +257,8 @@ class TestMetaBlockUnit:
                     mb_1.check(False, message_on_fail="THIS SHOULD NOT BE DISPLAYED")
                 with meta_block(2) as mb_2:
                     mb_2.check(True)
-        """)
+        """
+        )
         report = pytester.runpytest("--adaptavist", "-vv")
         _, _, etss = adaptavist_mock
         for call in etss.call_args_list:
@@ -241,7 +271,8 @@ class TestMetaBlockUnit:
     def test_meta_block_stop_method(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test Action.STOP_METHOD. We expect to not see step 2 and the second check of meta_block 1. TEST-T124 must be executed normally."""
 
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -254,7 +285,8 @@ class TestMetaBlockUnit:
             def test_TEST_T124(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True)
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         _, _, etss = adaptavist_mock
         assert etss.call_count == 2
@@ -265,7 +297,8 @@ class TestMetaBlockUnit:
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_meta_block_check_stop_session(self, pytester: pytest.Pytester):
         """Test Action.STOP_SESSION. We expect that TEST_T121 is executed. TEST_T123 fails and prevent execution of TEST_T124"""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T121(meta_block):
@@ -279,7 +312,8 @@ class TestMetaBlockUnit:
             def test_TEST_T124(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True)
-        """)
+        """
+        )
         outcome = pytester.runpytest("--adaptavist").parseoutcomes()
         assert outcome["passed"] == 1
         assert outcome["blocked"] == 2
@@ -287,7 +321,8 @@ class TestMetaBlockUnit:
     @pytest.mark.usefixtures("adaptavist_mock")
     def test_meta_block_check_fail_session(self, pytester: pytest.Pytester):
         """Test Action.FAIL_SESSION. We expect that TEST_T121 is executed. TEST_T123 fails and fails the whole session."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T121(meta_block):
@@ -301,7 +336,8 @@ class TestMetaBlockUnit:
             def test_TEST_T124(meta_block):
                 with meta_block(1):
                     assert True
-        """)
+        """
+        )
         outcome = pytester.runpytest("--adaptavist").parseoutcomes()
         assert outcome["failed"] == 1
         assert outcome["blocked"] == 1
@@ -315,7 +351,8 @@ class TestMetaBlockUnit:
 
     def test_meta_block_stop_exit_session(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test Action.EXIT_SESSION. We expect that TEST_T123 fails and exits the whole session."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -328,7 +365,8 @@ class TestMetaBlockUnit:
             def test_TEST_T124(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True)
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         _, _, etss = adaptavist_mock
         assert etss.call_count == 1
@@ -336,7 +374,8 @@ class TestMetaBlockUnit:
 
     def test_meta_block_fail_exit_session(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
         """Test Action.EXIT_SESSION. We expect that TEST_T123 fails and exits the whole session."""
-        pytester.makepyfile("""
+        pytester.makepyfile(
+            """
             import pytest
 
             def test_TEST_T123(meta_block):
@@ -349,7 +388,8 @@ class TestMetaBlockUnit:
             def test_TEST_T124(meta_block):
                 with meta_block(1) as mb_1:
                     mb_1.check(True)
-        """)
+        """
+        )
         pytester.runpytest("--adaptavist")
         _, _, etss = adaptavist_mock
         assert etss.call_count == 1
